#
#  For more information, please see: http://software.sci.utah.edu
#
#  The MIT License
#
#  Copyright (c) 2005-2006
#  Scientific Computing and Imaging Institute, University of Utah
#
#  License for the specific language governing rights and limitations under
#  Permission is hereby granted, free of charge, to any person obtaining a
#  copy of this software and associated documentation files (the "Software"),
#  to deal in the Software without restriction, including without limitation
#  the rights to use, copy, modify, merge, publish, distribute, sublicense,
#  and/or sell copies of the Software, and to permit persons to whom the
#  Software is furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included
#  in all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
#  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
#  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.
#

# Import wxManta gui and some system modules.
import wxManta
import getopt, sys

# Import the manta module, the mantainterface module which was %import'ed
# into swig/example.i is automatically included by the manta module.
from manta import *

# Import your new wrapped code.
from example import *

# Re-create the default scene using the example texture.
def initialize_scene( frame, engine ):

    # Create a scene object.
    scene = manta_new(Scene())
    scene.setBackground(manta_new(ConstantBackground(ColorDB.getNamedColor("SkyBlue3").scaled(0.5))))

    # Create the checker textures.
    checker1 = manta_new(CheckerTexture_Color(Color(RGBColor(.6,.6,.6)),
                                              Color(RGBColor(0,0,0)),
                                              Vector(1,0,0),
                                              Vector(0,1,0)))
    
    constant_color1 = manta_new(Constant_Color(Color(RGBColor(.6,.6,.6))))
    checker2 = manta_new(CheckerTexture_ColorComponent(0.2, 0.5, Vector(1,0,0),
                                             Vector(0,1,0)))

    # Create the floor shader.
    plane_matl = manta_new(Phong(checker1, constant_color1, 32, checker2))

    # Create a group for the scene.
    world = manta_new(Group())

    # Add the floor
    floor = manta_new(Parallelogram(plane_matl, Vector(-20,-20,0),
                                    Vector(40,0,0), Vector(0,40,0)))
    uniformmap = manta_new(UniformMapper())
    floor.setTexCoordMapper(uniformmap)
    world.add(floor)

    # Create the sphere texture.
    ex_texture = manta_new(ExampleTexture(ColorDB.getNamedColor("grey10"),
                                          ColorDB.getNamedColor("wheat")))

    material = manta_new(Lambertian(ex_texture))
        
    world.add(manta_new(Sphere(material, Vector(0,0,1.2), 1.0)))
    scene.setObject(world)
    
    # Lights.
    lights = manta_new(LightSet())
    lights.add(manta_new(PointLight(Vector(0,5,8), Color(RGBColor(.6,.1,.1)))))
    lights.add(manta_new(PointLight(Vector(5,0,8), Color(RGBColor(.1,.6,.1)))))
    lights.add(manta_new(PointLight(Vector(5,5,2), Color(RGBColor(.2,.2,.2)))))
    lights.setAmbientLight(manta_new(ConstantAmbient(Color.black())))
    #
    scene.setLights(lights)
    scene.getRenderParameters().maxDepth = 5

    engine.setScene( scene )

def usage():
    print "Usage: python test.py [options]"
    print "Where options contains one or more of:"
    print "-n --np=<threads>"

def main():

    # Default options.
    num_workers = 1

    # Parse command line options. Note these have to conform to getopt
    # So -np would be parsed as -n <space> p. Use --np=<threads> instead.
    try:
        opts, args = getopt.getopt(sys.argv[1:], "n:", ["np="] )

    except getopt.GetoptError:
        usage()
        sys.exit(2)
        
    for o, a in opts:
        if o in ("-n", "--np"):
            try:
                num_workers = int(a)
            except ValueError:
                usage()
                sys.exit(2)

        # Add additional command line args here.
        

    ###########################################################################
    # Create the application.
    app = wxManta.MantaApp( initialize_scene,
                            num_workers )


    ###########################################################################
    # Perform any additional setup

    # Start rendering.
    app.MainLoop()

if __name__ == "__main__":
    main()


